# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-10-19 12:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Cache',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('ip', models.GenericIPAddressField(verbose_name='IP address')),
                ('permanent', models.BooleanField(default=False, verbose_name='Permanent')),
            ],
            options={
                'verbose_name_plural': 'Cache',
                'verbose_name': 'Cache entry',
            },
        ),
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('inserted', models.DateTimeField(auto_now_add=True, verbose_name='inserted')),
                ('message', models.CharField(max_length=1024, verbose_name='message')),
            ],
            options={
                'verbose_name_plural': 'Log',
                'ordering': ('-inserted',),
                'verbose_name': 'Log message',
            },
        ),
    ]
